@@ -744,8 +744,7 @@ func (c *compiler) expr(expr ast.Expr) {
 			c.assignRoteIndex(e.Expr)
 		} else {
 			c.dupeIndexLValue(e.Expr)
-			c.expr(&ast.NumExpr{0}) // add 0 to coerce result to number
-			c.add(Add)
+			c.add(UnaryPlus) // coerce result to number
 			c.add(Dupe)
 			c.expr(&ast.NumExpr{1})
 			c.add(op)
@@ -1083,7 +1082,9 @@ func (c *compiler) regexIndex(r string) int {
 		return index // reuse existing constant
 	}
 	index := len(c.program.Regexes)
-	c.program.Regexes = append(c.program.Regexes, regexp.MustCompile(AddRegexFlags(r)))
+	re := regexp.MustCompile(AddRegexFlags(r))
+	re.Longest() // other awks use leftmost-longest matching
+	c.program.Regexes = append(c.program.Regexes, re)
 	c.indexes.regexes[r] = index
 	return index
 }
